@@ -23,7 +23,7 @@ our @EXPORT = qw( );
 # Preloaded methods go here.
 
 use overload '++' => sub { $_[0]->inc() },
-             '+=' => sub { $_[0]->add_to($_[1]) },
+	     '--' => sub { $_[0]->dec() },
              '='  => sub { $_[0]->clone() },
 	     'eq' => sub { $_[0]->equal($_[1]) },
 	     'ne' => sub { $_[0]->nequal($_[1]) },
